There are tests where you need some kind of environment variable or external service. For example:

- Etherscan
- GitHub

# Requirements

To run this folder, you'll need:

1. `ETHERSCAN_API_KEY` set to an Etherscan API key
2. `OPTIMISTIC_ETHERSCAN_API_KEY` set to an Etherscan-Optimism API key